@@ -34,8 +34,7 @@ setConstructorS3("AffymetrixCdfFile", function(...) {
   );
 
   # Parse attributes (all subclasses must call this in the constructor).
-  if (!is.null(this$.pathname))
-    setAttributesByTags(this);
+  setAttributesByTags(this)
 
   this;
 })
@@ -59,6 +58,7 @@ setMethodS3("getUnitTypesFile", "AffymetrixCdfFile", function(this, ...) {
 
 setMethodS3("getFileFormat", "AffymetrixCdfFile", function(this, ...) {
   pathname <- getPathname(this);
+  if (!isFile(pathname)) return(NA_character_)
 
   # Read CDF header
   raw <- readBin(pathname, what=raw(), n=10);
@@ -72,8 +72,7 @@ setMethodS3("getFileFormat", "AffymetrixCdfFile", function(this, ...) {
   if (rawToChar(raw[1:5]) == "[CDF]")
     return("v3 (text; ASCII)");
 
-  naValue <- as.character(NA);
-  return(naValue);
+  NA_character_
 })
 
 
@@ -244,7 +243,7 @@ setMethodS3("findByChipType", "AffymetrixCdfFile", function(static, chipType, ta
     pattern=sprintf("^%s%s$", fullname, extPattern),
     ...
   );
-  pathname <- do.call("findAnnotationDataByChipType", args=args);
+  pathname <- do.call(findAnnotationDataByChipType, args=args);
 
   # If not found, look for Windows shortcuts
   if (is.null(pathname)) {
@@ -254,7 +253,7 @@ setMethodS3("findByChipType", "AffymetrixCdfFile", function(static, chipType, ta
       pattern=sprintf("^%s%s[.]lnk$", fullname, extPattern),
       ...
     );
-    pathname <- do.call("findAnnotationDataByChipType", args=args);
+    pathname <- do.call(findAnnotationDataByChipType, args=args);
     if (!is.null(pathname)) {
       # ..and expand it
       pathname <- Arguments$getReadablePathname(pathname, mustExist=FALSE);
@@ -295,9 +294,13 @@ setMethodS3("findByChipType", "AffymetrixCdfFile", function(static, chipType, ta
 # @keyword IO
 #*/###########################################################################
 setMethodS3("getHeader", "AffymetrixCdfFile", function(this, ...) {
-  if (is.null(header <- this$.header))
-    header <- this$.header <- .readCdfHeader(getPathname(this));
-  header;
+  header <- this$.header
+  if (is.null(header)) {
+    if (!isFile(this)) return(NULL)
+    header <- .readCdfHeader(getPathname(this))
+    this$.header <- header
+  }
+  header
 }, private=TRUE)
 
 
@@ -307,6 +310,7 @@ setMethodS3("getPlatform", "AffymetrixCdfFile", function(this, ...) {
 
 
 setMethodS3("getChipType", "AffymetrixCdfFile", function(this, fullname=TRUE, ...) {
+  if (!isFile(this)) return(NA_character_)
   chipType <- getHeader(this)$chiptype;
 
   # Get the main chip type?
@@ -334,6 +338,7 @@ setMethodS3("getChipType", "AffymetrixCdfFile", function(this, fullname=TRUE, ..
 })
 
 setMethodS3("getDimension", "AffymetrixCdfFile", function(this, ...) {
+  if (!isFile(this)) return(c(NA_integer_, NA_integer_))
   header <- getHeader(this);
   c(nbrOfRows=header$rows, nbrOfColumns=header$cols);
 })
@@ -1318,7 +1323,12 @@ setMethodS3("convert", "AffymetrixCdfFile", function(this, chipType=getChipType(
   res <- .convertCdf(src, dest, ..., verbose=verbose2);
 
   # Return an AffymetrixCdfFile object for the new CDF
-  newInstance(this, dest);
+  cdf <- newInstance(this, dest)
+
+  ## Create checksum
+  cdfZ <- getChecksumFile(cdf)
+
+  cdf
 })
 
 
@@ -1632,7 +1642,7 @@ setMethodS3("validate", "AffymetrixCdfFile", function(this, ...) {
   # o HTHGU133A_Hs_ENTREZG.cdf (v 12.0.0) [as above]
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   unitNames <- getUnitNames(this);
-  assertUnits(((ns == 0L) & (nchar(unitNames) == 0L)), "%d unit(s) (i.e. %s) with zero unit groups and empty unit names: %s");
+  assertUnits(((ns == 0L) & (!nzchar(unitNames))), "%d unit(s) (i.e. %s) with zero unit groups and empty unit names: %s");
 
 
   invisible(this);
