@@ -530,7 +530,7 @@ setMethodS3("createUniqueCdf", "AffymetrixCdfFile", function(this, chipType=getC
   verbose && print(verbose, gc);
 
   # Rename temporary file
-  pathname <- popTemporaryFile(pathnameT, verbose=verbose);
+  popTemporaryFile(pathnameT, verbose=verbose);
 
   verbose && cat(verbose, "File pathname: ", pathname);
   verbose && print(verbose, file.info(pathname));
@@ -561,6 +561,9 @@ setMethodS3("createUniqueCdf", "AffymetrixCdfFile", function(this, chipType=getC
   stopifnot(length(cells) <= nbrOfCells(cdfU));
   stopifnot(identical(unique(diff(cells)), 1L));
 
+  ## Create checksum file
+  cdfUZ <- getChecksumFile(cdfU)
+
   verbose && exit(verbose);
 
   cdfU;
