@@ -6,7 +6,7 @@ setMethodS3("writeCdfByExcludingCells", "AffymetrixCdfFile", function(this, tags
 
   # Argument 'tags':
   tags <- Arguments$getCharacters(tags);
-  tags <- tags[nchar(tags) > 0];
+  tags <- tags[nzchar(tags)];
 
   # Argument 'cellsToExclude':
   cellsToExclude <- Arguments$getIndices(cellsToExclude, max=maxNbrOfCells);
@@ -199,7 +199,7 @@ setMethodS3("writeCdfByExcludingCells", "AffymetrixCdfFile", function(this, tags
   stopifnot(!any(is.element(cellsToExclude, cellsF)));
 
   # Rename temporary file
-  pathnameF <- popTemporaryFile(pathnameT, verbose=verbose);
+  popTemporaryFile(pathnameT, verbose=verbose);
 
   verbose && exit(verbose);
 
@@ -210,6 +210,9 @@ setMethodS3("writeCdfByExcludingCells", "AffymetrixCdfFile", function(this, tags
   cdfF <- newInstance(this, pathnameF);
   verbose && print(verbose, cdfF);
 
+  ## Create checksum file
+  cdfFZ <- getChecksumFile(cdfF)
+
   nbrOfCellsF <- length(cellsF);
   verbose && cat(verbose, "Number of cells in output CDF: %d", nbrOfCellsF);
   verbose && printf(verbose, "Number of cells excluded: %d (%.1f%%) of %d\n", nbrOfCells-nbrOfCellsF, 100*(nbrOfCells-nbrOfCellsF)/nbrOfCells, nbrOfCells);
