@@ -26,8 +26,7 @@ setConstructorS3("AromaChipTypeAnnotationFile", function(...) {
   this <- extend(AffymetrixFile(...), "AromaChipTypeAnnotationFile");
 
   # Parse attributes (all subclasses must call this in the constructor).
-  if (!is.null(this$.pathname))
-    setAttributesByTags(this);
+  setAttributesByTags(this)
 
   this;
 })
