@@ -30,7 +30,8 @@ setMethodS3("getImage", "AromaUnitTabularBinaryFile", function(this, transforms=
   z <- vector(mode=mode(values), 1);
   z <- matrix(z, nrow=nbrOfRows(cdf), ncol=nbrOfColumns(cdf));
   z[indexByRow(z, ugcMap[,"cell"])] <- values[ugcMap[,"unit"]];
-  rm(values, ugcMap);
+  # Not needed anymore
+  values <- ugcMap <- NULL;
   verbose && summary(verbose, as.vector(z));
   verbose && printf(verbose, "RAM: %.1fMB\n", object.size(z)/1024^2);
   verbose && exit(verbose);
