@@ -1,7 +1,7 @@
 setMethodS3("extractTheta", "ChipEffectSet", function(this, units=NULL, groups=NULL, ..., drop=FALSE, verbose=FALSE) {
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Validate arguments
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   cdf <- getCdf(this);
 
   # Argument 'units':
@@ -33,9 +33,9 @@ setMethodS3("extractTheta", "ChipEffectSet", function(this, units=NULL, groups=N
   }
 
 
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Get the UGC map
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   if (is.null(ugcMap)) {
     verbose && enter(verbose, "Getting (unit, group, cell) map");
     ugcMap <- getUnitGroupCellMap(this, units=units, verbose=less(verbose));
@@ -54,9 +54,9 @@ setMethodS3("extractTheta", "ChipEffectSet", function(this, units=NULL, groups=N
 
 
 
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Extract the thetas
-  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
+  # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   nbrOfGroups <- length(groups);
   nbrOfArrays <- length(this);
   dim <- c(nbrOfUnits, nbrOfGroups, nbrOfArrays);
@@ -64,8 +64,8 @@ setMethodS3("extractTheta", "ChipEffectSet", function(this, units=NULL, groups=N
   naValue <- as.double(NA);
   theta <- array(naValue, dim=dim, dimnames=dimnames);
   for (kk in seq_len(nbrOfArrays)) {
-    ce <- getFile(this, kk);
-    thetaKK <- extractTheta(ce, units=ugcMap, groups=groups, 
+    ce <- this[[kk]];
+    thetaKK <- extractTheta(ce, units=ugcMap, groups=groups,
                                                  verbose=less(verbose, 5));
     verbose && str(verbose, thetaKK);
     theta[,,kk] <- thetaKK;
