@@ -54,8 +54,7 @@ setConstructorS3("ParameterCelFile", function(..., encodeFunction=NULL, decodeFu
   );
 
   # Parse attributes (all subclasses must call this in the constructor).
-  if (!is.null(this$.pathname))
-    setAttributesByTags(this);
+  setAttributesByTags(this)
 
   this;
 })
