@@ -31,8 +31,7 @@ setConstructorS3("QualityAssessmentFile", function(...) {
   );
 
   # Parse attributes (all subclasses must call this in the constructor).
-  if (!is.null(this$.pathname))
-    setAttributesByTags(this);
+  setAttributesByTags(this)
 
   this;
 })
