@@ -34,8 +34,7 @@ setConstructorS3("SnpChipEffectFile", function(..., mergeStrands=FALSE) {
   );
 
   # Parse attributes (all subclasses must call this in the constructor).
-  if (!is.null(this$.pathname))
-    setAttributesByTags(this);
+  setAttributesByTags(this)
 
   this;
 })
