@@ -57,9 +57,9 @@ setFullNamesTranslator(dsC, df);
 sampleNames <- unique(getNames(dsC));
 
 dsList <- lapply(sampleNames, FUN=function(sampleName) {
-  ds <- extract(dsC, sampleName);
+  ds <- dsC[sampleName];
   lapply(c(T="T", N="N"), FUN=function(type) {
-    extract(ds, sapply(ds, hasTag, type));
+    ds[sapply(ds, hasTag, type)];
   });
 });
 names(dsList) <- sampleNames;
@@ -68,9 +68,9 @@ names(dsList) <- sampleNames;
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 # Extract (single) tumor-normal pairs
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-dfTList <- lapply(dsList, FUN=function(dsList) { getFile(dsList$T, 1) });
+dfTList <- lapply(dsList, FUN=function(dsList) { dsList$T[[1]] });
 dsT <- newInstance(dsList[[1]]$T, dfTList);
-dfNList <- lapply(dsList, FUN=function(dsList) { getFile(dsList$N, 1) });
+dfNList <- lapply(dsList, FUN=function(dsList) { dsList$N[[1]] });
 dsN <- newInstance(dsList[[1]]$T, dfNList);
 
 
@@ -103,7 +103,7 @@ setOption("PSCBS::reports/pscnSegmentationTransitions", TRUE);
 
 # Generate reports for tumor-normal pairs
 for (ii in 1:min(length(scs),5)) {
-  df <- getFile(scs, ii);
+  df <- scs[[ii]];
   fit <- loadObject(df);
   sampleName <- getFullName(df);
   pathname <- report(fit, sampleName=sampleName, studyName=getFullName(dsT), verbose=verbose);
